VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "MyAddin"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Attribute VB_Description = "VB6 Engineering AddIn"
Option Explicit

''''''''
''''''''
''''''''''''''''''''''''''''''''''''''''''''''''''
''''''''''''''''''''''''''''''''''''''''''''''''''
''
'' SeAddInSDK - Example of Addin integration with Solid Edge
''              When installed it add a simple toolbar and
''              a complete EdgeBar for property management
''
''
''  Created by Paolo Marani,  7-Oct-2002
''  (c)2002 by Engineering S.p.A. ITALY
''
''  This source code is freely redistributable
''
''''''''''''''''''''''''''''''''''''''''''''''''''
''''''''''''''''''''''''''''''''''''''''''''''''''

'Class for command processing
Private m_Commands As Commands

'CATIDs of all Solid Edge environment
Private Const CATID_SEPart = "{26618396-09d6-11d1-ba07-080036230602}"
Private Const CATID_SEDraft = "{08244193-b78d-11d2-9216-00c04f79be98}"
Private Const CATID_SESheetMtl = "{26618398-09d6-11d1-ba07-080036230602}"
Private Const CATID_SEAssembly = "{26618395-09d6-11d1-ba07-080036230602}"
Private Const CATID_SEWeldment = "{7313526a-276f-11d4-b64e-00c04f79b2bf}"

'Needed for implement the AddIn interface
Implements ISolidEdgeAddIn

Private Sub Class_Initialize()
    'MsgBox "The Solid Edge Sample Addin object is being initialized upon creation"
End Sub

' This method is called when the Addin is first loaded by Solid Edge
Private Sub ISolidEdgeAddIn_OnConnection(ByVal Application As Object, ByVal ConnectMode As SolidEdgeFramework.SeConnectMode, ByVal AddInInstance As SolidEdgeFramework.AddIn)
    Set m_Commands = New Commands
    
    ' Store the app dispatch for future use
    Set m_Commands.m_SEapp = Application
    
    ' Store the SolidEdge created addin object corresponding to myself
    Set m_Commands.m_myAddIn = AddInInstance
    
    ' Connect up the addin event set
    ' (can connect up here to any event set the addin is interested in)
    Set m_Commands.m_addinEvents = AddInInstance.AddInEvents
    
    On Error GoTo fail
    
    ' Forward application event interface
    Dim oApp As SolidEdgeFramework.Application
10  Set oApp = AddInInstance.Application
    Set m_Commands.m_AppEvents = Application
    Set oApp = Nothing
    
    ' Bring up a message box indicating the reason for the connection
    Select Case ConnectMode
        Case SeConnectMode.seConnectAtStartup
'            MsgBox "Startup!"
        Case SeConnectMode.seConnectByUser
'            MsgBox "Connect by User!"
        Case SeConnectMode.seConnectExternally
'            MsgBox "Connect Externally!"
    End Select
    
    ' Give SolidEdge a description of myself
    AddInInstance.Description = "AddIn SDK for Solid Edge"

    ' information
    'MsgBox "The addin's VB assigned GUID is " & AddInInstance.Guid
    
    ' Give SolidEdge the current version of the addin's GUI, which will be stored
    ' by SolidEdge. If this changes the next time it connects to SolidEdge, the
    ' SolidEdge will purge any menu entries and comman buttons it put up there earlier
    ' and the addin will have to redo those.
    AddInInstance.GuiVersion = 1 ' Addin has to update this when GUI version changes
     
    ' Make sure I am visible to the SolidEdge user in the Addins menu
    ' (this is the default, so not really necessary)
    AddInInstance.Visible = True
    Exit Sub
fail:
    MsgBox "(" & Erl & ") - " & Err.Description, vbCritical
End Sub

' This method is called the first time the environment is switched to in Solid Edge AND
' the addin has registered itself as interested in adding commands to that environment.
' The input CATID is the CATID of the environment being switched to. This is called ONCE per
' addin for each environent that addin is interested in.
Private Sub ISolidEdgeAddIn_OnConnectToEnvironment(ByVal EnvCatID As String, ByVal pEnvironmentDispatch As Object, ByVal bFirstTime As Boolean)
'    Dim CommandNames(Number_Of_Buttons) As String
'    Dim CommandIDs(Number_Of_Buttons) As Long
    Dim i As Integer
    
    ' Set up the AddInInfo that SolidEdge needs.
    '
    ' The command string consists of the following six parts:
    ' part 1: The name of the command. This should be as unique as possible becasue this will
    '         become the tag of the command. Use the company name etc. to make it unique.
    '         Since this tag is stored by SolidEdge to ensure identity, it SHOULD NOT BE
    '         internationalized/localized.
    ' part 2: Text displayed on the menu entry for the command
    ' part 3: String displayed on the status bar
    ' part 4: Tootip string
    ' part 5: The string that will be the "OnAction" string. If this string is specified, it means
    '         the addin is adding a macro button and not a command
    ' part 6: If the "OnAction" is specified, then this is the "Parameter Text" string, i.e. additional
    '         parameters for the macro button.
    
    ' Since no option base statement is present, "0" is the first index. Also, internal
    ' SE code currently expects a zero index to be the first entry, for now.
    
    'CommandNames()     Button specific initialization names
    'CommandIDs()       Addin needs to keep track of these
    
'    CommandNames(0) = SetCommandName( _
'        "CMD Button 1", "Menu Button 1", "This is the Button 1 of the AddIn SDK", "ToolTip Button 1", "", "")
'    CommandIDs(0) = CmdId_Button1
'
'    CommandNames(1) = SetCommandName( _
'        "CMD Button 2", "Menu Button 2", "This is the Button 2 of the AddIn SDK", "ToolTip Button 2", "", "")
'    CommandIDs(1) = CmdId_Button2
'
'    CommandNames(2) = SetCommandName( _
'        "CMD Button 3", "Menu Button 3", "This is the Button 3 of the AddIn SDK", "ToolTip Button 3", "", "")
'    CommandIDs(2) = CmdId_Button3

    ' We are not interested in connecting to an environment to which we are not adding buttons
    Select Case LCase(EnvCatID)
        Case CATID_SEPart
'            MsgBox "Addin connecting to Part Environment..."
        Case CATID_SEDraft
'            MsgBox "Addin connecting to Draft Environment..."
        Case CATID_SEAssembly
'            MsgBox "Addin connecting to Assembly Environment..."
        Case CATID_SESheetMtl
'            MsgBox "Addin connecting to SheetMtl Environment..."
        Case CATID_SEWeldment
'            MsgBox "Addin connecting to Weldment Environment..."
    End Select
        
    ' IMPORTANT: The SetAddinInfo method MUST be called EVEY time an addin connects up
    ' ---------  with Solid Edge, unlike the "AddCommandBarButton" method below, which
    '            must be called ONLY during the very first time the addin is connecting.
    '            Solid Edge is geared to remember the GUI that the user added but not the
    '            commands.
    '
    ' The parameters in order are:
    ' - Handle to the resource DLL
    ' - Catergory ID of the Solid Edge environment that we want our commands to run in
    ' - The string that we want to appear in the Toolbar category box, during customization
    '   (i.e. when we run Tools->Customize in SolidEdge)
    ' - Resource ID of the medium color bitmap resource glyph
    ' - Resource ID of the large  color bitmap resource glyph
    ' - Resource ID of the medium monochrome bitmap resource glyph
    ' - Resource ID of the large monochrome bitmap resource glyph
    ' - Number of commands being added
    ' - array of IDs of the commands added(these IDs are maintained by the addin)
    
    ' NOTE: The monochrome bitmaps are IDs of the color bitmaps, which is not right.
    '       (This needs to be changed)
'    Call m_Commands.m_myAddIn.SetAddInInfo( _
'        App.hInstance, _
'        EnvCatID, _
'        "VB AddIn SDK", _
'        101, _
'        102, _
'        103, _
'        104, _
'        Number_Of_Buttons, _
'        CommandNames, _
'        CommandIDs)
    
    ' This is output in CommandIDs above, which is an input/output array. The output
    ' IDs are those assigned to the commands within Solid Edge
    
    With m_Commands
'        .m_Button1_ID = CommandIDs(0)
'        .m_Button2_ID = CommandIDs(1)
'        .m_Button3_ID = CommandIDs(2)
    End With

    If bFirstTime Then
        
        ' Add toolbar buttons since this is the FIRST time the add-in is being loaded into
        ' the environment that is being made active.  Toolbar buttons are automatically
        ' remembered from session to session, so we should only add the commands and
        ' toolbar buttons once, and not very time Solid Edge starts up.
        '
        ' The parameters are:
        ' - The CATID of the environment to which this button is being added
        ' - The toolbar name which this button needs to be added to
        ' - The command ID (the addin's command id and not the one assigned by Solid Edge)
        
        With m_Commands
'            AddCmdBarButton EnvCatID, TOOLBAR_NAME, CmdId_Button1
'            AddCmdBarButton EnvCatID, TOOLBAR_NAME, CmdId_Button2
'            AddCmdBarButton EnvCatID, TOOLBAR_NAME, CmdId_Button3, True
        End With
        
    End If
End Sub

Private Sub AddCmdBarButton(ByVal EnvironmentCatID As String, ByVal CommandBarName As String, ByVal CommandID As Long, Optional ByVal Separator As Boolean = False)
    Dim oBtn As SolidEdgeFramework.CommandBarButton
    Set oBtn = m_Commands.m_myAddIn.AddCommandBarButton(EnvironmentCatID, CommandBarName, CommandID)
    If Separator Then oBtn.BeginGroup = True
    Set oBtn = Nothing
End Sub

Private Function SetCommandName(sCmdName As String, sMenuName As String, sStatusBar As String, sToolTip As String, sOnAction As String, sArgument As String)
    SetCommandName = sCmdName & vbLf & sMenuName & vbLf & sStatusBar & vbLf & sToolTip & vbLf & sOnAction & vbLf & sArgument
End Function

Private Sub ISolidEdgeAddIn_OnDisconnection(ByVal DisconnectMode As SolidEdgeFramework.SeDisconnectMode)
    ' VERY VERY important to free any Solid Edge resources
    Set m_Commands.m_SEapp = Nothing
    Set m_Commands.m_addinEvents = Nothing
    Set m_Commands.m_myAddIn = Nothing
    Set m_Commands = Nothing
End Sub

